@@ -45,10 +45,7 @@ class SMTPConnection extends EventEmitter {
     constructor(options) {
         super(options);
 
-        this.id = crypto
-            .randomBytes(8)
-            .toString('base64')
-            .replace(/\W/g, '');
+        this.id = crypto.randomBytes(8).toString('base64').replace(/\W/g, '');
         this.stage = 'init';
 
         this.options = options || {};
@@ -73,10 +70,7 @@ class SMTPConnection extends EventEmitter {
 
         this.customAuth = new Map();
         Object.keys(this.options.customAuth || {}).forEach(key => {
-            let mapKey = (key || '')
-                .toString()
-                .trim()
-                .toUpperCase();
+            let mapKey = (key || '').toString().trim().toUpperCase();
             if (!mapKey) {
                 return;
             }
@@ -267,12 +261,12 @@ class SMTPConnection extends EventEmitter {
                         tnx: 'dns',
                         source: opts.host,
                         resolved: resolved.host,
-                        cached: !!resolved._cached
+                        cached: !!resolved.cached
                     },
                     'Resolved %s as %s [cache %s]',
                     opts.host,
                     resolved.host,
-                    resolved._cached ? 'hit' : 'miss'
+                    resolved.cached ? 'hit' : 'miss'
                 );
                 Object.keys(resolved).forEach(key => {
                     if (key.charAt(0) !== '_' && resolved[key]) {
@@ -305,12 +299,12 @@ class SMTPConnection extends EventEmitter {
                         tnx: 'dns',
                         source: opts.host,
                         resolved: resolved.host,
-                        cached: !!resolved._cached
+                        cached: !!resolved.cached
                     },
                     'Resolved %s as %s [cache %s]',
                     opts.host,
                     resolved.host,
-                    resolved._cached ? 'hit' : 'miss'
+                    resolved.cached ? 'hit' : 'miss'
                 );
                 Object.keys(resolved).forEach(key => {
                     if (key.charAt(0) !== '_' && resolved[key]) {
@@ -338,12 +332,12 @@ class SMTPConnection extends EventEmitter {
                         tnx: 'dns',
                         source: opts.host,
                         resolved: resolved.host,
-                        cached: !!resolved._cached
+                        cached: !!resolved.cached
                     },
                     'Resolved %s as %s [cache %s]',
                     opts.host,
                     resolved.host,
-                    resolved._cached ? 'hit' : 'miss'
+                    resolved.cached ? 'hit' : 'miss'
                 );
                 Object.keys(resolved).forEach(key => {
                     if (key.charAt(0) !== '_' && resolved[key]) {
@@ -424,11 +418,7 @@ class SMTPConnection extends EventEmitter {
 
         this._auth = authData || {};
         // Select SASL authentication method
-        this._authMethod =
-            (this._auth.method || '')
-                .toString()
-                .trim()
-                .toUpperCase() || false;
+        this._authMethod = (this._auth.method || '').toString().trim().toUpperCase() || false;
 
         if (!this._authMethod && this._auth.oauth2 && !this._auth.credentials) {
             this._authMethod = 'XOAUTH2';
@@ -558,6 +548,16 @@ class SMTPConnection extends EventEmitter {
                                 '\u0000' +
                                 this._auth.credentials.pass,
                             'utf-8'
+                        ).toString('base64'),
+                    // log entry without passwords
+                    'AUTH PLAIN ' +
+                        Buffer.from(
+                            //this._auth.user+'\u0000'+
+                            '\u0000' + // skip authorization identity as it causes problems with some servers
+                                this._auth.credentials.user +
+                                '\u0000' +
+                                '/* secret */',
+                            'utf-8'
                         ).toString('base64')
                 );
                 return;
@@ -598,7 +598,7 @@ class SMTPConnection extends EventEmitter {
 
         // ensure that callback is only called once
         let returned = false;
-        let callback = function() {
+        let callback = function () {
             if (returned) {
                 return;
             }
@@ -883,16 +883,21 @@ class SMTPConnection extends EventEmitter {
         });
 
         this.upgrading = true;
-        this._socket = tls.connect(opts, () => {
-            this.secure = true;
-            this.upgrading = false;
-            this._socket.on('data', this._onSocketData);
+        // tls.connect is not an asynchronous function however it may still throw errors and requires to be wrapped with try/catch
+        try {
+            this._socket = tls.connect(opts, () => {
+                this.secure = true;
+                this.upgrading = false;
+                this._socket.on('data', this._onSocketData);
 
-            socketPlain.removeListener('close', this._onSocketClose);
-            socketPlain.removeListener('end', this._onSocketEnd);
+                socketPlain.removeListener('close', this._onSocketClose);
+                socketPlain.removeListener('end', this._onSocketEnd);
 
-            return callback(null, true);
-        });
+                return callback(null, true);
+            });
+        } catch (err) {
+            return callback(err);
+        }
 
         this._socket.on('error', this._onSocketError);
         this._socket.once('close', this._onSocketClose);
@@ -950,8 +955,9 @@ class SMTPConnection extends EventEmitter {
      * Send a command to the server, append \r\n
      *
      * @param {String} str String to be sent to the server
+     * @param {String} logStr Optional string to be used for logging instead of the actual string
      */
-    _sendCommand(str) {
+    _sendCommand(str, logStr) {
         if (this._destroyed) {
             // Connection already closed, can't send any more data
             return;
@@ -966,7 +972,7 @@ class SMTPConnection extends EventEmitter {
                 {
                     tnx: 'client'
                 },
-                (str || '').toString().replace(/\r?\n$/, '')
+                (logStr || str || '').toString().replace(/\r?\n$/, '')
             );
         }
 
@@ -1425,18 +1431,21 @@ class SMTPConnection extends EventEmitter {
 
         // Decode from base64
         let base64decoded = Buffer.from(challengeString, 'base64').toString('ascii'),
-            hmac_md5 = crypto.createHmac('md5', this._auth.credentials.pass);
+            hmacMD5 = crypto.createHmac('md5', this._auth.credentials.pass);
 
-        hmac_md5.update(base64decoded);
+        hmacMD5.update(base64decoded);
 
-        let hex_hmac = hmac_md5.digest('hex');
-        let prepended = this._auth.credentials.user + ' ' + hex_hmac;
+        let prepended = this._auth.credentials.user + ' ' + hmacMD5.digest('hex');
 
         this._responseActions.push(str => {
             this._actionAUTH_CRAM_MD5_PASS(str, callback);
         });
 
-        this._sendCommand(Buffer.from(prepended).toString('base64'));
+        this._sendCommand(
+            Buffer.from(prepended).toString('base64'),
+            // hidden hash for logs
+            Buffer.from(this._auth.credentials.user + ' /* secret */').toString('base64')
+        );
     }
 
     /**
@@ -1481,7 +1490,11 @@ class SMTPConnection extends EventEmitter {
             this._actionAUTHComplete(str, callback);
         });
 
-        this._sendCommand(Buffer.from(this._auth.credentials.pass + '', 'utf-8').toString('base64'));
+        this._sendCommand(
+            Buffer.from((this._auth.credentials.pass || '').toString(), 'utf-8').toString('base64'),
+            // Hidden pass for logs
+            Buffer.from('/* secret */', 'utf-8').toString('base64')
+        );
     }
 
     /**
@@ -1711,7 +1724,11 @@ class SMTPConnection extends EventEmitter {
             this._responseActions.push(str => {
                 this._actionAUTHComplete(str, isRetry, callback);
             });
-            this._sendCommand('AUTH XOAUTH2 ' + this._auth.oauth2.buildXOAuth2Token(accessToken));
+            this._sendCommand(
+                'AUTH XOAUTH2 ' + this._auth.oauth2.buildXOAuth2Token(accessToken),
+                //  Hidden for logs
+                'AUTH XOAUTH2 ' + this._auth.oauth2.buildXOAuth2Token('/* secret */')
+            );
         });
     }
 
