@@ -1,5 +1,5 @@
 /* eslint no-unused-expressions:0, no-invalid-this:0, prefer-arrow-callback: 0 */
-/* globals beforeEach, afterEach, describe, it */
+/* globals beforeEach, afterEach, describe, it, before */
 
 'use strict';
 
@@ -200,6 +200,30 @@ describe('Shared Funcs Tests', function () {
             });
         });
 
+        it('should set content from a stream and preserve other properties', function (done) {
+            let mail = {
+                data: {
+                    attachment: {
+                        filename: 'message.html',
+                        content: fs.createReadStream(__dirname + '/fixtures/message.html')
+                    }
+                }
+            };
+            shared.resolveContent(mail.data, 'attachment', function (err, value) {
+                expect(err).to.not.exist;
+                expect(mail).to.deep.equal({
+                    data: {
+                        attachment: {
+                            filename: 'message.html',
+                            content: Buffer.from('<p>Tere, tere</p><p>vana kere!</p>\n')
+                        }
+                    }
+                });
+                expect(value).to.deep.equal(Buffer.from('<p>Tere, tere</p><p>vana kere!</p>\n'));
+                done();
+            });
+        });
+
         it('should return an error', function (done) {
             let mail = {
                 data: {
@@ -236,8 +260,7 @@ describe('Shared Funcs Tests', function () {
                 let mail = {
                     data: {
                         attachment: {
-                            path:
-                                'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg=='
+                            path: 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg=='
                         }
                     }
                 };
@@ -287,8 +310,7 @@ describe('Shared Funcs Tests', function () {
                 let mail = {
                     data: {
                         attachment: {
-                            path:
-                                'data:image/png;charset=iso-8859-1;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg=='
+                            path: 'data:image/png;charset=iso-8859-1;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg=='
                         }
                     }
                 };
@@ -357,4 +379,159 @@ describe('Shared Funcs Tests', function () {
             expect(shared.encodeXText('tere t\tre')).to.equal('tere+20t+09re');
         });
     });
+
+    describe('#resolveHostname tests', function () {
+        let networkInterfaces;
+
+        before(function (done) {
+            networkInterfaces = JSON.parse(JSON.stringify(shared.networkInterfaces));
+            done();
+        });
+
+        beforeEach(function (done) {
+            shared.dnsCache.clear();
+
+            done();
+        });
+
+        afterEach(function (done) {
+            // reset network interfaces
+            Object.keys(shared.networkInterfaces).forEach(key => {
+                delete shared.networkInterfaces[key];
+            });
+
+            Object.keys(networkInterfaces).forEach(key => {
+                shared.networkInterfaces[key] = networkInterfaces[key];
+            });
+
+            done();
+        });
+
+        it('should resolve a single IPv4 entry', function (done) {
+            shared.resolveHostname({ host: 'ipv4.single.dev.ethereal.email' }, (err, result) => {
+                expect(err).to.not.exist;
+                expect(result).to.deep.equal({
+                    servername: 'ipv4.single.dev.ethereal.email',
+                    host: '54.36.85.114',
+                    cached: false
+                });
+                shared.resolveHostname({ host: 'ipv4.single.dev.ethereal.email' }, (err, result) => {
+                    expect(err).to.not.exist;
+                    expect(result).to.deep.equal({
+                        servername: 'ipv4.single.dev.ethereal.email',
+                        host: '54.36.85.114',
+                        cached: true
+                    });
+                    done();
+                });
+            });
+        });
+
+        it('should resolve multiple IPv4 entries', function (done) {
+            let found = new Set();
+            let count = 0;
+
+            let resolveNext = () => {
+                if (count++ > 100) {
+                    expect(new Error('too many tries')).to.not.exist;
+                    return done();
+                }
+                if (found.size === 3) {
+                    return done();
+                }
+
+                shared.resolveHostname({ host: 'ipv4.multi.dev.ethereal.email' }, (err, result) => {
+                    expect(err).to.not.exist;
+
+                    expect(result.servername).to.equal('ipv4.multi.dev.ethereal.email');
+                    expect(result.host).to.exist;
+
+                    found.add(result.host);
+
+                    resolveNext();
+                });
+            };
+
+            resolveNext();
+        });
+
+        it('should resolve a single IPv6 entry', function (done) {
+            // ensure that there is a single Ipv6 interface "available"
+            Object.keys(shared.networkInterfaces).forEach(key => {
+                delete shared.networkInterfaces[key];
+            });
+
+            shared.networkInterfaces.en0 = [
+                {
+                    address: 'fe80::184e:7a8e:2d67:be86',
+                    netmask: 'ffff:ffff:ffff:ffff::',
+                    family: 'IPv6',
+                    mac: 'f0:18:98:57:76:44',
+                    internal: false,
+                    cidr: 'fe80::184e:7a8e:2d67:be86/64',
+                    scopeid: 6
+                }
+            ];
+
+            shared.resolveHostname({ host: 'ipv6.single.dev.ethereal.email' }, (err, result) => {
+                expect(err).to.not.exist;
+                expect(result).to.deep.equal({
+                    servername: 'ipv6.single.dev.ethereal.email',
+                    host: '2001:41d0:304:200::baa9',
+                    cached: false
+                });
+                shared.resolveHostname({ host: 'ipv6.single.dev.ethereal.email' }, (err, result) => {
+                    expect(err).to.not.exist;
+                    expect(result).to.deep.equal({
+                        servername: 'ipv6.single.dev.ethereal.email',
+                        host: '2001:41d0:304:200::baa9',
+                        cached: true
+                    });
+                    done();
+                });
+            });
+        });
+
+        it('should fail resolving a single IPv6 entry', function (done) {
+            // ensure that there is a single Ipv4 interface "available"
+            Object.keys(shared.networkInterfaces).forEach(key => {
+                delete shared.networkInterfaces[key];
+            });
+
+            shared.networkInterfaces.en0 = [
+                {
+                    address: '192.168.1.175',
+                    netmask: '255.255.255.0',
+                    family: 'IPv4',
+                    mac: 'f0:18:98:57:76:44',
+                    internal: false,
+                    cidr: '192.168.1.175/24'
+                }
+            ];
+
+            shared.resolveHostname({ host: 'ipv6.single.dev.ethereal.email' }, err => {
+                expect(err).to.exist;
+                done();
+            });
+        });
+
+        it('should fail missing address', function (done) {
+            shared.resolveHostname({ host: 'missing.single.dev.ethereal.email' }, err => {
+                expect(err).to.exist;
+                done();
+            });
+        });
+
+        it('should return provided IP', function (done) {
+            shared.resolveHostname({ host: '1.2.3.4', servername: 'example.com' }, (err, result) => {
+                expect(err).to.not.exist;
+                expect(result).to.deep.equal({
+                    servername: 'example.com',
+                    host: '1.2.3.4',
+                    cached: false
+                });
+                done();
+            });
+        });
+    });
 });
